// KeywordManager.h
// (c) 2003-2004 exeal

#ifndef _KEYWORD_MANAGER_H_
#define _KEYWORD_MANAGER_H_

#include "AscensionCommon.h"
#include "..\..\Manah\Object.h"
#include <vector>


namespace Ascension {

// CKeywordManager class definition
/////////////////////////////////////////////////////////////////////////////

///	L[[h̊Ǘ
class CKeywordManager : public Manah::CObject {
	// RXgN^
public:
	CKeywordManager();
	CKeywordManager(const CKeywordManager& rhs);
	~CKeywordManager();

	// \bh
public:
	void	Add(const string_t& strKeyword);									// L[[h̒ǉ
	void	Clear();															// L[[h̑S폜
	bool	Find(const char_t* strText, length_t cch, bool bIgnoreCase) const;	// L[[ȟ

	// f[^o
private:
	std::vector<char_t*>	m_vecKeywords;	// \L[[h
};

} // namespace Ascension

#endif /* _KEYWORD_MANAGER_H_ */

/* [EOF] */